userFlaviencancel
reporust_rebootcancel

8,164 Commits over 1,004 Days - 0.34cph!

15 Days Ago
EntityFlag_Toggle events now skips one shot sounds the first time it runs, when entity spawns - fixes furnaces playing their extinguish sound when spawned (many other entities had the same issue: campfire, mixing table..) - it didn't cause any perf issues before: the sound manager drops one shot sounds beyond their audible range, and entities spawned at network range, far beyond it - now that we have base occlusion, you could hear them spawning which was an issue for both gameplay and performance
15 Days Ago
merge from entityspawning_optims
15 Days Ago
Pooled industrial conveyors switch their hum off when retired
15 Days Ago
merge from arabic_ellipsis_fix
15 Days Ago
merge from genericpopup_rrp_fix
15 Days Ago
Forgot a file
15 Days Ago
Fixed oversized and misplaced ellipsis "..." on Arabic text, was causing "Line breaking recursion max threshold hit"
15 Days Ago
Fixed generic popup sorting issue with rrp enabled
15 Days Ago
merge from genericpopup_rrp_fix
15 Days Ago
Fixed flying horse bullshit
15 Days Ago
merge from flyinghorse_fix
15 Days Ago
merge from console_autocomplete_improvements
15 Days Ago
merge from console_autocomplete_improvements
15 Days Ago
Fixed entity and item auto completion always showing SERVER realm
15 Days Ago
Missed Poolable.cs
15 Days Ago
Same change as 166970 but for all furnace prefabs (furnace, electric furnace, large furnace)
15 Days Ago
Conveyors are poolable We prewarm 10 copies
15 Days Ago
We now prefill our pool with up to 30 copies of the most used io entities. The first time you load a big base will be a tad faster at the expense of more upfront memory You're going to load them as soon as you load the local zerg base anyway
15 Days Ago
Added SoundPlayerCull to industrial conveyors looping hum sound. It was spawned regardless of distance then paused Editor profiling, 30 conveyors spawned 150m away: - 9ms -> 2.3ms total - ~470us -> ~220us per conveyor spawn - Sound.DoUpdate per frame: 112us -> 20us (the 30 paused hums were still updated every frame)
15 Days Ago
Removed the pref to skip unity event listener baking in editor, wasn't necessary (renamed the branch to entityspawning_optims)
15 Days Ago
Added entity/item autocompletion to more commands
15 Days Ago
spawngrid and teleportany autocomplete entity names
15 Days Ago
merge from console_autocomplete_improvements
15 Days Ago
Optimized entities with flag toggles spawning: EntityFlag_Toggle now bakes its listeners at prefab preprocessing and calls them directly instead of invoking its UnityEvent The first UnityEvent invoke on every new instance looked its listeners up by reflection. Rough profiling from the editor, loading in a mix of 248 entities (io, locks, doors and some random deployables) EntityFlag.DoUpdate 26ms -> 2ms total ~100us -> ~9us per entity ~940 KB -> ~231 KB total
16 Days Ago
merge from map_optims
16 Days Ago
Fixed deep sea layer nuking all the monument markers Fixed shop markers cache being filled with junk when disconnecting/reconnecting
16 Days Ago
merge from quickcraft_optims
16 Days Ago
Optimized prefab lookups by path, we now cache exact spelling hits. Makes each FindPrefab ~7x faster on repeat calls (was around 6us per call in builds, up to 0.5ms in frames that spawn a lot when entering network range of a base) We could make prefab paths case sensitive instead, but I'm not gonna change the million callers and that could break plugins
16 Days Ago
Fixed QuickCraft.FindItems spending ~2ms checking if you own a dlc after looting an item, SteamDownloadableContent now caches the answer for each DLC
16 Days Ago
merge from teamui_optims
16 Days Ago
Fixed the player name cache being cleared on every team update, causing the team UI to refilter every name through Steam (~1.5ms every 4s with 7 teammates)
16 Days Ago
merge from animalanimation_optims
16 Days Ago
Fixed AnimalAnimation out of range errors
16 Days Ago
merge from notices_rtl_fix
16 Days Ago
Fixed item dropped and item pickup notices not working with RTL languages
16 Days Ago
Fixed CraftingNotice allocating every frame when crafting an item Also converted them to RustText so they can display RTL languages
16 Days Ago
merge from boateffects_optims
16 Days Ago
Optimized MotorRowboat.Update, it has a slow water height check for its effects, around 0.10ms - culled by distance - skipped when stationnary for >3s
16 Days Ago
Fixed AnimalAnimation allocating 80 bytes for each footstep
16 Days Ago
merge from animalanimation_optims
16 Days Ago
▊▉▉▋▋▋█ ▉ ▋▌▍ ▇▉▌▇▊▌ ▄▅ ▆▍▋▉ ▉▉▄▆▊▊▅ ▌▄ ▋█▋ ▊▆▋▋▄▉▇▋ ▄▄▌▅▌▄▍▆▆▌▅▊▍▍▍▆ ▋ ▉▌▍▉▍▍▉▄ ▅ ▋█▅▇▄▊▊▍ ██▋▍█▊ ▋▍▉▅▊▌▋▊▆▉▄▉▋█▆▄▅▆▄▊▇█▅▍▋█▍▄▉▉▉▋▄▅▆▉█▋▍▆█▄▆▉▆▉▍▅▋▇▇█▌▋▆▆▌▊█▅▌▋▄▊
16 Days Ago
merge from texturestreaming_texturepropertiescache_fix
16 Days Ago
Fixed TextureStreaming never filling its shader texture property cache, every belt swap was allocating all shader property names (18KB down to 1KB per swap)
16 Days Ago
merge from lightlod_optims
16 Days Ago
Cache DistanceFlareLOD fading action
16 Days Ago
Fixed shadowlights convar handler stacking up across editor play sessions
16 Days Ago
Fixed LightLOD.Awake and OnDestroy allocating The shadow caching convar callback was subscribed per light, every light spawn and destroy copied the whole handler list (had 1500 lights, 10KB every time)
16 Days Ago
Cache AmbientLightLOD fading action
16 Days Ago
merge from drinkingpoint_optims
16 Days Ago
merge from drinkingpoint_optims